==> csmash_0.6.4.2.orig.tar.gz: csmash-0.6.4.2/NetShakeCut.h <==
/* $Id: NetShakeCut.h,v 1.1 2001/12/20 17:36:49 nan Exp $ */

// Copyright (C) 2001  $B?@Fn(B $B5H9((B(Kanna Yoshihiro)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#ifndef _NetShakeCut_
#define _NetShakeCut_
#include "ShakeCut.h"

class NetShakeCut : public ShakeCut {
public:
  NetShakeCut();
  NetShakeCut(long side);
  NetShakeCut( long playerType, long side, double x, double y, double z, 
	       double vx, double vy, double vz,long status, long swing, 
	       long swingType, bool swingSide, long afterSwing,
	       long swingError, double targetX, double targetY,
	       double eyeX, double eyeY, double eyeZ,
	       long pow, double spin, double stamina, long statusMax );
  virtual ~NetShakeCut();

  virtual bool Move( unsigned long *KeyHistory, long *MouseXHistory,
		     long *MouseYHistory, unsigned long *MouseBHistory,
		     int Histptr );
};

#endif // _NetShakeCut_

==> csmash_0.6.6.orig.tar.gz: csmash-0.6.6/NetShakeCut.h <==
/* $Id: NetShakeCut.h,v 1.2 2003/07/16 16:03:38 nan Exp $ */

// Copyright (C) 2001  $B?@Fn(B $B5H9((B(Kanna Yoshihiro)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#ifndef _NetShakeCut_
#define _NetShakeCut_
#include "ShakeCut.h"

class NetShakeCut : public ShakeCut {
public:
  NetShakeCut();
  NetShakeCut(long side);
  NetShakeCut( long playerType, long side, double x, double y, double z, 
	       double vx, double vy, double vz,long status, long swing, 
	       long swingType, bool swingSide, long afterSwing,
	       long swingError, double targetX, double targetY,
	       double eyeX, double eyeY, double eyeZ,
	       long pow, double spin, double stamina, long statusMax );
  virtual ~NetShakeCut();

  virtual bool Move( SDL_keysym *KeyHistory, long *MouseXHistory,
		     long *MouseYHistory, unsigned long *MouseBHistory,
		     int Histptr );
};

#endif // _NetShakeCut_
